OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fajl je otpremljen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fajl za otpremljivanje premašuje upload_max_filesize direktivu u php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fajl za otpremanje premašuje MAX_FILE_SIZE navedenu u HTML obrascu",
    "The file was only partially uploaded" : "Fajl je parcijalno otpremljen",
    "No file was uploaded" : "Nijedan fajl nije otpremljen",
    "Missing a temporary folder" : "Nedostaje privremena fascikla",
    "Could not write file to disk" : "Ne mogu da upišem fajl na disk",
    "A PHP extension stopped the file upload" : "PHP ekstenzija je zaustavila otpremanje fajla",
    "File not found" : "Fajl nije nađen",
    "Translate" : "Prevedi",
    "Reload" : "Ponovo učitaj",
    "Guest" : "Gost",
    "guest" : "gost",
    "Offline" : "Van mreže",
    "Bold" : "Podebljano",
    "Italic" : "Kurziv",
    "Link" : "Veza",
    "Undo" : "Opozovi",
    "Cancel" : "Poništi",
    "Replace" : "Zameni postojeću",
    "Upload" : "Otpremi",
    "Edit" : "Uredi",
    "Source code" : "Izvorni kôd",
    "Done" : "Gotovo",
    "Details" : "Detalji",
    "Choose" : "Odaberi",
    "Info" : "Info",
    "Warning" : "Upozorenje"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
